==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Videotallennus on käynnissä. Sulje ikkuna?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Kuva</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Vaihda kameraa</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Sinulla ei ole lupaa käyttää tätä kansiota</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Virheellinen kansio</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Tiedoston sijainti</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Laukaise</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Sarjakuvaus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Laukaisimen viive</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ulostulo</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Talletusmuoto</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kpl</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kpl</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera on kuvan ja videon sieppaustyökalu, joka käyttää tietokoneen kameraa tai verkkokameraa.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Tiedostoa ei tallennettu</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Tallenna nimellä:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Kuva:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Tarkkuuden asetukset</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Tarkkuus:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Kuvat:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videot:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Äänitehosteet</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Peilaus</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Salama</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Lopeta tallennus</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikavalinnat</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Lopeta kuvaaminen</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Pikavalikko</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Ota kuva</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Tallenna video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Lopeta kuvaaminen</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Eloisa</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Lämmin</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kylmä</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filmi</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Mustavalko</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Salama</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ei</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Kaappauksen viive</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Suodattimet</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Valotus</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Verkkokameraa ei löytynyt</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Verkkokamera on käytössä</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Lopeta tallennus</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Tallennus on käynnissä. Suljetaanko ikkuna?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Kuva</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Vaihda kameraa</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Sinulla ei ole lupaa käyttää tätä kansiota</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Virheellinen kansio</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Tiedoston sijainti</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Laukaise</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Sarjakuvaus</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Laukaisimen viive</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ulostulo</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Talletusmuoto</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kpl</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kpl</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera on työkalu kuvan ja videon tallentamiseen. Käyttää tietokoneen kameraa tai verkkokameraa.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Tiedostoa ei tallennettu</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Tallenna nimellä:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Kuva:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Tarkkuuden asetukset</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Tarkkuus:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Kuvat:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videot:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Äänitehosteet</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Peilaus</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Salama</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Ruudukkoviivat</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 viivaa</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 viivaa</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Suurin tarkkuus:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Lopeta tallennus</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikavalinnat</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Lopeta kuvaaminen</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Pikavalikko</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Ota kuva</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Tallenna video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Lopeta kuvaaminen</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Eloisa</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Lämmin</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Kylmä</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filmi</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Mustavalko</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Salama</translation>
    </message>
    <message>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Ei</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Kaappauksen viive</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Suodattimet</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Valotus</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Verkkokameraa ei löytynyt</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Verkkokamera on käytössä</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Lopeta tallennus</translation>
    </message>
</context>
</TS>
